Struct google_cloudmonitoring2_beta2::api::MetricDescriptor[][src]

pub struct MetricDescriptor {
    pub description: Option<String>,
    pub labels: Option<Vec<MetricDescriptorLabelDescriptor>>,
    pub name: Option<String>,
    pub project: Option<String>,
    pub type_descriptor: Option<MetricDescriptorTypeDescriptor>,
}

A metricDescriptor defines the name, label keys, and data type of a particular metric.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

description: Option<String>

Description of this metric.

labels: Option<Vec<MetricDescriptorLabelDescriptor>>

Labels defined for this metric.

name: Option<String>

The name of this metric.

project: Option<String>

The project ID to which the metric belongs.

type_descriptor: Option<MetricDescriptorTypeDescriptor>

Type description for this metric.